<?php
namespace ChangeCommerce\Core\Model\Config;

use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\Encryption\EncryptorInterface;

class Data extends AbstractHelper
{
    /**
     * @var EncryptorInterface
     */
    protected $encryptor;

    /**
     * @param Context $context
     * @param EncryptorInterface $encryptor
     */
    public function __construct(
        Context $context,
        EncryptorInterface $encryptor,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
    )
    {
        parent::__construct($context);
        $this->encryptor = $encryptor;
        $this->scopeConfig = $scopeConfig;
    }

    /*
     * @return bool
     */
    public function isEnabled($scope = \Magento\Store\Model\ScopeInterface::SCOPE_STORE)
    {
        return $this->scopeConfig->isSetFlag(
            'changecommerce_core/general/enabled',
            $scope
        );
    }

    public function isEnabledRaw($scope = \Magento\Store\Model\ScopeInterface::SCOPE_STORE)
    {
        return $this->scopeConfig->getValue(
            'changecommerce_core/general/enabled',
            $scope
        );
    }

    /*
     * @return string
     */
    public function getStoreId($scope = \Magento\Store\Model\ScopeInterface::SCOPE_STORE)
    {
        return $this->scopeConfig->getValue(
            'changecommerce_core/general/storeid',
            $scope
        );
    }

    /*
     * @return string
     */
    public function getSecret($scope = \Magento\Store\Model\ScopeInterface::SCOPE_STORE)
    {
        $secret = $this->scopeConfig->getValue(
            'changecommerce_core/general/secret',
            $scope
        );
        $secret = $this->encryptor->decrypt($secret);
        
        return $secret;
    }

    /*
     * @return string
     */
    public function getOrderCreateWebhookUri($scope = ScopeConfigInterface::SCOPE_TYPE_DEFAULT)
    {
        return $this->scopeConfig->getValue(
            'changecommerce_core/general/order_create_webhook_uri',
            $scope
        );
    }

    /*
     * @return string
     */
    public function getOrderCreditWebhookUri($scope = ScopeConfigInterface::SCOPE_TYPE_DEFAULT)
    {
        return $this->scopeConfig->getValue(
            'changecommerce_core/general/order_credit_webhook_uri',
            $scope
        );
    }

    /*
     * @return string
     */
    public function getOrderCancelWebhookUri($scope = ScopeConfigInterface::SCOPE_TYPE_DEFAULT)
    {
        return $this->scopeConfig->getValue(
            'changecommerce_core/general/order_cancel_webhook_uri',
            $scope
        );
    }
}